@@ -10,12 +10,38 @@
 //#include <QtXml>
 //#include <QXmlSimpleReader>
 
+class QLabelW: public QLabel {
 
-// TODO after insert a field with password, then click to see, crash when pushing password button
+public:
+	QLabelW(const QString &text, bool isLabel, QWidget *parent=0, Qt::WindowFlags f=0) : QLabel (text, parent, f) {
+		this->isLabel = isLabel;
+	}
+	QLabelW(QWidget *parent=0, Qt::WindowFlags f=0): QLabel (parent, f) {
+	}
+	~QLabelW() {
+	}
+protected:
+	bool isLabel;
+    void mousePressEvent(QMouseEvent *ev) {
+    	//qDebug () << "click on field " << this->userData(0);
+    	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
+    	if (f->type == TYPE_URL && !isLabel) {
+    		QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
+    	}
+    	else {
+			//if (f != NULL)
+			//qDebug () << "pressed " << f->value;
+			QClipboard *cb = QApplication::clipboard();
+			cb->setText(f->value);
+    	}
+    }
+};
 
 DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
 {
+	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+
 	isNew = target == NULL;
 
 	this->target = target;
@@ -58,7 +84,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 		menuBar()->addAction("Mirror Back Pict.", this, SLOT(mirrorBack()));
 		menuBar()->addAction("Delete Face Pict.", this, SLOT(deleteCardFace()));
 		menuBar()->addAction("Delete Back Pict.", this, SLOT(deleteCardBack()));
-		menuBar()->addAction("Modify field", this, SLOT(modifyFields()));
+		menuBar()->addAction("Modify fields", this, SLOT(modifyFields()));
 		//TODO menuBar()->addAction("Delete field", this, SLOT(addNewField()));
 		//TODO menuBar()->addAction("Modify field", this, SLOT(addNewField()));
 	}
@@ -323,14 +349,16 @@ void DetailWindow::showFields () {
 			}
 			else {
 				if (field->value.length() > 0) {
-					QLabel * nameLabel = new QLabel(field->name, this);
+					QLabel * nameLabel = new QLabelW(field->name, true, this);
 					nameLabel->setFont (QFont("arial", 11, 1, true));
 					nameLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 					nameLabel->setContentsMargins(0, 0, 10, 0);
-					//nameLabel->setContextMenuPolicy(Qt::NoContextMenu);
+
+					nameLabel->setUserData(0, new ButtonInfo (field));
+
 					componentLayout->addWidget(nameLabel, pos + 1, 1, 1, 2);
 
-					if (field->type == TYPE_PASSWORD || field->name.contains("password", Qt::CaseInsensitive)) {
+					if (field->type == TYPE_PASSWORD) {// || field->name.contains("password", Qt::CaseInsensitive)) {
 						QPushButton * nameLineEdit = new QPushButton("Click to see", this);
 						//nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
 						componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 2);
@@ -341,9 +369,12 @@ void DetailWindow::showFields () {
 						QObject::connect(nameLineEdit, SIGNAL(clicked()), signalMapper, SLOT(map()));
 					}
 					else {
-						QLabel * nameLineEdit = new QLabel(field->value, this);
-						//nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
+						QLabel * nameLineEdit = new QLabelW(field->value, false, this);
+						nameLineEdit->setUserData(0, new ButtonInfo (field));
 						componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
+//						if (field->type == TYPE_URL) {
+//							nameLineEdit->setFoStyle(QStyle::)
+//						}
 					}
 				}
 			}
@@ -361,8 +392,11 @@ void DetailWindow::showFields () {
 
 void DetailWindow::clickPass (QWidget * _wid) {
 	QPushButton * b = (QPushButton *)_wid;
+
 	//qDebug () << "click on field " << b->userData(0);
+
 	TargetField * f = ((ButtonInfo *)b->userData(0))->field;
+
 	if (b->text() == f->value) {
 		b->setText("Click to see");
 	}
@@ -373,15 +407,18 @@ void DetailWindow::clickPass (QWidget * _wid) {
 
 void DetailWindow::changeFields (int a) {
 
-	//qDebug () << "selectedt " << a;
+	qDebug () << "selected type " << a;
 
 	for (int i = target->fields.size(); i > 0; i--) {
 		TargetField * field = target->fields [i - 1];
 
 		if (field->value.length() == 0) {
+			qDebug () << "remove" << field->name;
 			target->fields.removeAt(i - 1);
 			delete field;
 		}
+		else
+			qDebug () << "keep" << field->name;
 	}
 
 	for (int i = 0; i < parent->fieldsByType [a]->size(); i++) {
@@ -744,40 +781,40 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 	QDialogButtonBox* dlgBtnBox = new QDialogButtonBox(this);
 	dlgBtnBox->setOrientation(Qt::Vertical);
 
-	previousButton = new QPushButton(QIcon(":/resources/icon_previous.png"), "Previous", this);
-	previousButton->setFixedHeight(70);
+	previousButton = new QPushButton(QIcon(":/resources/icon_previous.png"), "", this);
+	//previousButton->setFixedHeight(70);
 	previousButton->setContextMenuPolicy(Qt::NoContextMenu);
 	previousButton->setFocusPolicy(Qt::NoFocus);
 	previousButton->setIconSize(QSize(48, 48));
 	QObject::connect(previousButton, SIGNAL(clicked()), this, SLOT(previous()));
 	dlgBtnBox->addButton(previousButton, QDialogButtonBox::ActionRole);
 
-	nextButton = new QPushButton(QIcon(":/resources/icon_next.png"), "Next", this);
-	nextButton->setFixedHeight(70);
+	nextButton = new QPushButton(QIcon(":/resources/icon_next.png"), "", this);
+	//nextButton->setFixedHeight(70);
 	nextButton->setContextMenuPolicy(Qt::NoContextMenu);
 	nextButton->setFocusPolicy(Qt::NoFocus);
 	nextButton->setIconSize(QSize(48, 48));
 	QObject::connect(nextButton, SIGNAL(clicked()), this, SLOT(next()));
 	dlgBtnBox->addButton(nextButton, QDialogButtonBox::ActionRole);
 
-	deleteButton = new QPushButton(QIcon(":/resources/icon_delete.png"), "Delete", this);
-	deleteButton->setFixedHeight(70);
+	deleteButton = new QPushButton(QIcon(":/resources/icon_delete.png"), "", this);
+	//deleteButton->setFixedHeight(70);
 	deleteButton->setContextMenuPolicy(Qt::NoContextMenu);
 	deleteButton->setFocusPolicy(Qt::NoFocus);
 	deleteButton->setIconSize(QSize(48, 48));
 	QObject::connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteCurrent()));
 	dlgBtnBox->addButton(deleteButton, QDialogButtonBox::ActionRole);
 
-	QPushButton * newButton = new QPushButton(QIcon(":/resources/icon_add_new.png"), "Add new", this);
-	newButton->setFixedHeight(70);
+	QPushButton * newButton = new QPushButton(QIcon(":/resources/icon_add_new.png"), "", this);
+	//newButton->setFixedHeight(70);
 	newButton->setContextMenuPolicy(Qt::NoContextMenu);
 	newButton->setFocusPolicy(Qt::NoFocus);
 	newButton->setIconSize(QSize(48, 48));
 	QObject::connect(newButton, SIGNAL(clicked()), this, SLOT(addNew()));
 	dlgBtnBox->addButton(newButton, QDialogButtonBox::ActionRole);
 
-	QPushButton * closeButton = new QPushButton("Close", this);
-	closeButton->setFixedHeight(70);
+	QPushButton * closeButton = new QPushButton("Save && Close", this);
+	//closeButton->setFixedHeight(70);
 	closeButton->setContextMenuPolicy(Qt::NoContextMenu);
 	closeButton->setFocusPolicy(Qt::NoFocus);
 	closeButton->setIconSize(QSize(48, 48));
