@@ -6,10 +6,13 @@
 #include "LoginDialog.h"
 #include "Constants.h"
 
-LoginDialog::LoginDialog(eWallet *paTarget): QWidget((QWidget*)paTarget)
+LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)paTarget)
 {
 	setContextMenuPolicy(Qt::NoContextMenu);
 
+	isFirstTime = firstTime;
+	NTimes = 0;
+
 	QHBoxLayout * layout = new QHBoxLayout(this);
 	QGridLayout * componentLayout = new QGridLayout ();
 	this->parent = paTarget;
@@ -23,21 +26,23 @@ LoginDialog::LoginDialog(eWallet *paTarget): QWidget((QWidget*)paTarget)
 
 	QSignalMapper * signalMapper = new QSignalMapper(this);
 
-	label = new QLabel("", this);
+	label = new QLineEdit("", this);
 	label->setContextMenuPolicy(Qt::NoContextMenu);
-	label->setAlignment(Qt::AlignCenter);
+	label->setEchoMode(QLineEdit::Password); //EchoOnEdit);
+	//label->setFocus(Qt::TabFocusReason);
+	label->setMaxLength(16);
+	//label->setAlignment(Qt::AlignCenter);
 
-	
 	for (int i = 0; i < 12; i++) {
 		QString text ('0' + i + 1);
 
 		if (i == 9) {
 			text = "Ok";
 			imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_accept.png"),
-			imageButton[i] ->setFixedHeight(60);
+			imageButton[i] ->setFixedHeight(70);
 			imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
 			imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-			imageButton[i] ->setIconSize(QSize(20, 20));
+			//imageButton[i] ->setIconSize(QSize(20, 20));
 			componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 			//signalMapper->setMapping(imageButton[i], text);
@@ -47,10 +52,10 @@ LoginDialog::LoginDialog(eWallet *paTarget): QWidget((QWidget*)paTarget)
 			if (i == 10) {
 				text = "0";
 				imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
-				imageButton[i] ->setFixedHeight(60);
+				imageButton[i] ->setFixedHeight(70);
 				imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
 				imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-				imageButton[i] ->setIconSize(QSize(20, 20));
+				//imageButton[i] ->setIconSize(QSize(20, 20));
 				componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 				signalMapper->setMapping(imageButton[i], text);
@@ -60,10 +65,10 @@ LoginDialog::LoginDialog(eWallet *paTarget): QWidget((QWidget*)paTarget)
 				if (i == 11) {
 					text = "Clear";
 					imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_clear.png"),
-					imageButton[i] ->setFixedHeight(60);
+					imageButton[i] ->setFixedHeight(70);
 					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
 					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-					imageButton[i] ->setIconSize(QSize(20, 20));
+					//imageButton[i] ->setIconSize(QSize(20, 20));
 					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 					//signalMapper->setMapping(imageButton[i], text);
@@ -71,10 +76,10 @@ LoginDialog::LoginDialog(eWallet *paTarget): QWidget((QWidget*)paTarget)
 					QObject::connect(imageButton[i], SIGNAL(clicked()), this, SLOT(clearS()));
 				} else {
 					imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
-					imageButton[i] ->setFixedHeight(60);
+					imageButton[i] ->setFixedHeight(70);
 					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
 					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-					imageButton[i] ->setIconSize(QSize(20, 20));
+					//imageButton[i] ->setIconSize(QSize(20, 20));
 					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 					signalMapper->setMapping(imageButton[i], text);
@@ -102,22 +107,33 @@ LoginDialog::LoginDialog(eWallet *paTarget): QWidget((QWidget*)paTarget)
 	QObject::connect(aboutButton, SIGNAL(clicked()), this, SLOT(about()));
 	dlgBtnBox->addButton(aboutButton, QDialogButtonBox::ActionRole);
 
-	QPushButton * deleteButton = new QPushButton(QIcon(":/resources/exit.png"), "Exit", this);
+	QPushButton * deleteButton = new QPushButton(QIcon(":/resources/delete.png"), "Delete DB", this);
 	deleteButton->setFixedHeight(70);
 	deleteButton->setContextMenuPolicy(Qt::NoContextMenu);
 	deleteButton->setFocusPolicy(Qt::NoFocus);
 	deleteButton->setIconSize(QSize(48, 48));
-	QObject::connect(deleteButton, SIGNAL(clicked()), QApplication::instance(), SLOT(quit()));
+	QObject::connect(deleteButton, SIGNAL(clicked()), this->parent, SLOT(deleteDB()));
 	dlgBtnBox->addButton(deleteButton, QDialogButtonBox::ActionRole);
 
+	QPushButton * exitButton = new QPushButton(QIcon(":/resources/exit.png"), "Exit", this);
+	exitButton->setFixedHeight(70);
+	exitButton->setContextMenuPolicy(Qt::NoContextMenu);
+	exitButton->setFocusPolicy(Qt::NoFocus);
+	exitButton->setIconSize(QSize(48, 48));
+	QObject::connect(exitButton, SIGNAL(clicked()), QApplication::instance(), SLOT(quit()));
+	dlgBtnBox->addButton(exitButton, QDialogButtonBox::ActionRole);
+
 	layout->addLayout(componentLayout);
 	layout->setAlignment(componentLayout, Qt::AlignVCenter);
 
 	layout->addWidget(dlgBtnBox);
 	layout->setAlignment(dlgBtnBox, Qt::AlignBottom);
 
-
 	setLayout(layout);
+
+	this->setFocus ();
+	label->setFocus ();
+	this->focusNextChild();
 }
 
 LoginDialog::~LoginDialog()
@@ -125,16 +141,17 @@ LoginDialog::~LoginDialog()
 }
 void LoginDialog::about()
 {
-	if (aboutDialogDlg.isNull()) {
-		aboutDialogDlg = new AboutDialog(this);
-		aboutDialogDlg->showMaximized();
-#ifdef Q_WS_MAEMO_5
-		aboutDialogDlg->setAttribute(Qt::WA_Maemo5StackedWindow);
-#endif
-		aboutDialogDlg->setAttribute(Qt::WA_DeleteOnClose);
-        //connect(detailWindowEdit, SIGNAL(destroyed(QObject*)), this, SLOT(windowDestroyed(QObject*)));
-        aboutDialogDlg->show();
-	}
+    QMessageBox::about(this, "About qtWallet", TEXT_ABOUT);
+//    if (aboutDialogDlg.isNull()) {
+//		aboutDialogDlg = new AboutDialog(this);
+//		aboutDialogDlg->showMaximized();
+//#ifdef Q_WS_MAEMO_5
+//		aboutDialogDlg->setAttribute(Qt::WA_Maemo5StackedWindow);
+//#endif
+//		aboutDialogDlg->setAttribute(Qt::WA_DeleteOnClose);
+//        //connect(detailWindowEdit, SIGNAL(destroyed(QObject*)), this, SLOT(windowDestroyed(QObject*)));
+//        aboutDialogDlg->show();
+//	}
 }
 void LoginDialog::clearS()
 {
@@ -143,51 +160,98 @@ void LoginDialog::clearS()
 }
 
 void LoginDialog::acceptS() {
+	if (current.length() == 0) {
+		if (messageBox.isNull()) {
+			messageBox = new QMessageBox(this);
+			messageBox->information(this, "Wallet", "Password is required", QMessageBox::Ok);
+		}
+		delete messageBox;
+		messageBox = 0;
+
+		return;
+	}
+
+	if (isFirstTime) {
+		if (NTimes == 0) {
+			newPassword = current;
+			NTimes = 1;
+
+			clearS ();
+
+			if (messageBox.isNull()) {
+				messageBox = new QMessageBox(this);
+				messageBox->information(this, "Wallet", "For verification, please, enter your password again", QMessageBox::Ok);
+			}
+			delete messageBox;
+			messageBox = 0;
+
+			return;
+		}
+		if (NTimes == 1) {
+			if (newPassword != current) {
+				NTimes = 0;
+				clearS ();
+				if (messageBox.isNull()) {
+					messageBox = new QMessageBox(this);
+					messageBox->information(this, "Wallet", "Invalid password, please enter again", QMessageBox::Ok);
+				}
+				delete messageBox;
+				messageBox = 0;
+
+				return;
+			}
+		}
+	}
+
 	if (parent->openDataBase (current)) {
 		//close();
 	}
 	else {
-
-		label->setText ("");
-		current = "";
+		clearS ();
 	}
 }
 
 void LoginDialog::select(const QString& a) {
 	if (current.size() < KEY_SIZE) {
 		current += a;
-		label->setText (QString ("************************").right(current.size()));		
+		label->setText (current); //QString ("************************").right(current.size()));
 	}
 }
 
-void LoginDialog::keyPressEvent(QKeyEvent* event) {
-	//qDebug()<<"key pressed " << event->key();
-	
-	if (event->key() >= Qt::Key_0 && event->key() <= Qt::Key_9) {
-		if (current.size() < KEY_SIZE) {
-			current += (char)(event->key());
-			label->setText (QString ("************************").right(current.size()));		
-		}
-		event->accept();
-	}
-	else {
-		if (event->key() == Qt::Key_Backspace || event->key() == Qt::Key_Delete) {
-			if (current.size () > 0) {
-				current = current.left (current.size ()-1);
-				label->setText (QString ("************************").right(current.size()));						
-			}
-			event->accept();
-		}
-		else {
-			if (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) {
-				event->accept();
-				acceptS();
-			}
-			else {
-				QWidget::keyPressEvent(event);
-			}
-		}
-	}
+//void LoginDialog::keyPressEvent(QKeyEvent* event) {
+//	//qDebug()<<"key pressed " << event->key();
+//
+//	if (event->key() >= Qt::Key_0 && event->key() <= Qt::Key_9) {
+//		if (current.size() < KEY_SIZE) {
+//			current += (char)(event->key());
+//			label->setText (current); //QString ("************************").right(current.size()));
+//		}
+//		event->accept();
+//	}
+//	else {
+//		if (event->key() == Qt::Key_Backspace || event->key() == Qt::Key_Delete) {
+//			if (current.size () > 0) {
+//				current = current.left (current.size ()-1);
+//				label->setText (current); //QString ("************************").right(current.size()));
+//			}
+//			event->accept();
+//		}
+//		else {
+//			if (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) {
+//				event->accept();
+//				acceptS();
+//			}
+//			else {
+//				event->accept();//QWidget::keyPressEvent(event);
+//QLineEdit::keyPressEvent(event);
+//			}
+//		}
+//	}
+//}
+
+void LoginDialog::resetF () {
+	isFirstTime = true;
+	NTimes = 0;
 }
 /*
 void LoginDialog::focusOutEvent ( QFocusEvent * event ) {
