@@ -10,28 +10,37 @@
 #include <QFileDialog>
 
 class eWallet;
+class AboutDialog;
 
-class LoginDialog : public QDialog
+class LoginDialog : public QWidget
 {
 	Q_OBJECT
 
 public:
-	LoginDialog(eWallet * paTarget);
+	LoginDialog(bool firstTime, eWallet * paTarget);
 	~LoginDialog();
 
-	void keyPressEvent(QKeyEvent* event);
+	void resetF ();
+	//void keyPressEvent(QKeyEvent* event);
 
-public slots:
+private slots:
 	void select(const QString& a);
 	void acceptS();
 	void clearS();
+	void about();
 
 private:
+	QPointer<AboutDialog> aboutDialogDlg;
+	QPointer <QMessageBox> messageBox;
 	//void focusOutEvent ( QFocusEvent * event );
 	QString current;
 	QString repeat;
 	eWallet * parent;
 	
-	QLabel * label;
+	int NTimes;
+	bool isFirstTime;
+	QString newPassword;
+
+	QLineEdit * label;
 };
 #endif // LOGINDIALOG_H
