@@ -1,25 +1,36 @@
 /*
  * Copyright (c) 2010 David Galindo <nowheremanmail@gmail.com>
  *
-// TODO  several files? or several wallets in database?
+// TODO several files? or several wallets in database?
 // TODO export to a file with pictures!!!??
 // TODO import picture from camera
 // TODO modify picture (zoom, ...)
-// TODO support for portaint
+// TODO support for portrain
 // TODO final images
  * TODO strong encryption with characters
- * TODO core dump when clicked normal key on login
- *
- *
+ * TODO check that export images get the right size
+ * TODO image size when no credit card (axa)
+ * TODO free list resources
+ * TODO after change type it is not refreshed on list
+ * TODO implements copy of information field (and images?)
+ * TODO allow to change password
+ * TODO use hilton notifications and banner???
+ * TODO check types on import
+ * TODO sort after insert new card
+ * TODO add warn message when import and export!
  */
 
 #include "eWallet.h"
 #include "Constants.h"
 #include "DatabaseManager.h"
 #include <Qt>
+#include <QtGui>
 #include <QFile>
 #include <QDBusInterface>
 #include <QDBusConnection>
+#include <QDesktopServices>
+#include <QListView>
+
 //#ifdef Q_WS_MAEMO_5
 //#include <mce/mode-names.h>
 //#include <mce/dbus-names.h>
@@ -27,37 +38,24 @@
 
 DatabaseManager * dbManager;
 
-eWallet::eWallet(QWidget *parent) :
-		QMainWindow(parent)
+eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 {
+	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+
+	ascSort = true;
+	currentFilter = "";
+
+	//this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 
-//qDBusRegisterMetaType<Property>();
-//qDBusRegisterMetaType< QList<Property> >();
 	loadTypesAndFields ();
 
 	::dbManager = new DatabaseManager(this);
 
 	askPassword ();
 
-//	QDBusInterface *interface = new QDBusInterface(MCE_SERVICE, MCE_REQUEST_PATH,
-//                                   MCE_REQUEST_IF, QDBusConnection::systemBus(),
-//                                   this);
-//
-//    QDBusMessage reply = interface->call(MCE_DISPLAY_SIG);
-//    if (reply.type() == QDBusMessage::ErrorMessage)
-//        qDebug() << "error? " << reply.errorMessage();
-
 	QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
 	bool success = conn.connect("","", QString("com.nokia.mce.signal"/*MCE_SIGNAL_IF*/), QString("display_status_ind"/*MCE_DISPLAY_SIG*/) , this, SLOT(listenInactivity(QString)));
-//	bool success = conn.connect(QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH), QString(MCE_SIGNAL_IF), QString(MCE_DISPLAY_SIG) /*MCE_DISPLAY_SIG MCE_DEVLOCK_MODE_GET MCE_DISPLAY_STATUS_GET MCE_INACTIVITY_STATUS_GET*/, this, SLOT(listenInactivity(QString)));
-//	//bool success = conn.connect("com.nokia.mce","/com/nokia/mce/signal","com.nokia.mce.signal", MCE_TKLOCK_MODE_GET, this, SLOT(listenInactivity(string)));
-
-	qDebug() << "SUCCESS : " << success;
-
-	//timer = new QTimer(this);
-	//connect(timer, SIGNAL(timeout()), this, SLOT(lockWallet()));
-	//timer->start(5000);
-	//showList  ();
+	//bool success = conn.connect("","", QString(MCE_SIGNAL_IF), QString(MCE_DISPLAY_SIG) , this, SLOT(listenInactivity(QString)));
 }
 
 void eWallet::showList () {
@@ -66,16 +64,20 @@ void eWallet::showList () {
 	//                         // Central widget and Layout
 	centralWidget = new QWidget(this);
 
-	setContextMenuPolicy(Qt::DefaultContextMenu);
-	centralWidget->setContextMenuPolicy(Qt::DefaultContextMenu);
+//	setContextMenuPolicy(Qt::DefaultContextMenu);
+//	centralWidget->setContextMenuPolicy(Qt::DefaultContextMenu);
 
 	vboxlayout = new QVBoxLayout;
 	vboxlayout->setSpacing(0);
 	vboxlayout->setMargin(0);
 	// Custom list box
-	fnListWidget = new QFNListWidget(this);
+
+	fnListWidget = new QListWidget(this);
 	vboxlayout->addWidget(fnListWidget);
 
+	QObject::connect(fnListWidget, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(selectItem(QListWidgetItem *)));
+	QObject::connect(fnListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(selectDItem(QListWidgetItem *)));
+
 	inputWidget = new QHBoxLayout;
 	inputWidget->setContentsMargins(2, 2, 2, 0);
 	vboxlayout->addLayout(inputWidget);
@@ -96,7 +98,7 @@ void eWallet::showList () {
 	searchField->hide ();
 	hideSearch->hide ();
 
-	showTargets ();
+	showTargets (true);
 
 	centralWidget->setLayout(vboxlayout);
 	setCentralWidget(centralWidget);
@@ -106,6 +108,22 @@ void eWallet::showList () {
 	centralWidget->setFocus ();
 }
 
+void eWallet::selectItem(QListWidgetItem * item) {
+	if (fnListWidget->currentItem() != item) {
+		fnListWidget->setCurrentItem(item);
+	}
+	Target * target = list.at(fnListWidget->currentRow());
+	viewTarget(target);
+}
+
+void eWallet::selectDItem(QListWidgetItem * item) {
+	if (fnListWidget->currentItem() != item) {
+		fnListWidget->setCurrentItem(item);
+	}
+	Target * target = list.at(fnListWidget->currentRow());
+	editTarget(target);
+}
+
 void eWallet::listenInactivity(QString s) {
 	//qDebug () << "HELLO " << s;
 	if (s == QString("off") && ::dbManager->isReady ()) {
@@ -139,13 +157,26 @@ void eWallet::listenInactivity(QString s) {
 }
 
 void eWallet::textChanged (const QString & text) {
-	//qDebug () << text;
-
+	currentFilter = text;
 	filterBy (text);
 }
 
 void eWallet::filterBy (const QString & s) {
-	fnListWidget->filterBy (s);
+	for (int i = 0; i < list.size (); i++) {
+		Target * target = list.at(i);
+
+		if (s.length() == 0) {
+			fnListWidget->item(i)->setHidden(false);
+		}
+		else {
+			if (target->name.contains(s, Qt::CaseInsensitive)) {
+				fnListWidget->item(i)->setHidden(false);
+			}
+			else {
+				fnListWidget->item(i)->setHidden(true);
+			}
+		}
+	}
 }
 
 void eWallet::_cancelSearch () {
@@ -166,6 +197,22 @@ void eWallet::lockWallet () {
 	askPassword ();
 }
 
+void eWallet::deleteDB () {
+	if (messageBox.isNull()) {
+		messageBox = new QMessageBox(this);
+		int b = messageBox->information(this, "Wallet", "Are you sure you want to remove all your data? You will lost all your data", QMessageBox::Yes, QMessageBox::No);
+		if (b == QMessageBox::Yes) {
+			::dbManager->reset ();
+
+			if (!loginDialogDlg.isNull()) {
+				loginDialogDlg->resetF ();
+			}
+		}
+	}
+	delete messageBox;
+	messageBox = 0;
+}
+
 bool eWallet::openDataBase (QString pas)
 {
 	bool res = ::dbManager->openDB(pas);
@@ -279,13 +326,10 @@ void eWallet::loadTypesAndFields () {
 	  }
 }
 
-void eWallet::timerEvent(QTimerEvent* event) {
-
-}
 void eWallet::keyPressEvent(QKeyEvent* event) {
 	//qDebug()<<"key pressed " << event->key();
 	
-	if (searchField->isHidden()) {
+	if (searchField != NULL && searchField->isHidden()) {
 		cancelSearch->show ();
 		searchField->show ();
 		hideSearch->show ();
@@ -295,116 +339,171 @@ void eWallet::keyPressEvent(QKeyEvent* event) {
 
 		event->accept();
 	}
+	else {
+		event->accept();
+	}
 	//timer->stop();
 	//timer->start(5000);
 }
 
+bool sortTargetsASC (const Target * f, const Target * g) {
+	return f->name.toLower() < g->name.toLower();
+}
+bool sortTargetsDES (const Target * f, const Target * g) {
+	return f->name.toLower() > g->name.toLower();
+}
 
-void eWallet::showTargets()
+QPixmap eWallet::getImage (Target * target) {
+	QPixmap image;
+	if (target->getPictureSmall() != NULL) {
+		image = QPixmap::fromImage (*target->getPictureSmall());
+
+		// at this moment we don't need anymore original images!
+		target->freeResources();
+	} else {
+		QString tmp = ":/resources/empty_";
+		tmp += target->type.simplified().replace(' ', '_');
+		tmp += ".png";
+
+		if (QResource (tmp).isValid()) {
+			image = QPixmap (tmp);
+		}
+		else {
+			image = QPixmap (":/resources/empty_Others.png");
+		}
+	}
+	return image;
+}
+void eWallet::showTargets(bool reset)
 {
 	// Clean previous items from the layout
 	fnListWidget->clear();
 
 	//QPixmap available(":/resources/icon_available.png");
 	//QPixmap notavailable(":/resources/icon_notavailable.png");
+	if (reset) {
+		list.clear ();
+		list = ::dbManager->getTargets ("");
+	}
 
-	list.clear ();
-	list = ::dbManager->getTargets ("");
+	if (ascSort)
+		qSort (list.begin(),list.end(),sortTargetsASC);
+	else
+		qSort (list.begin(),list.end(),sortTargetsDES);
+
+	fnListWidget->setIconSize (QSize (SMALL_WIDTH, SMALL_HEIGH));
+	//fnListWidget->setContentsMargins(10, 1, 0, 1);
 
 	for (int i = 0; i < list.size (); i++) {
-		QFNListItem* listitem = new QFNListItem(list.at(i), this);
-		fnListWidget->addItem(listitem, Qt::AlignTop | Qt::AlignLeft);
+		Target * target = list.at(i);
+
+		QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name, fnListWidget);
+		//listitem->set(target->getSummary());
+		fnListWidget->addItem(listitem);
 		
-		QObject::connect(listitem, SIGNAL(viewTarget(Target*)),
-                      this, SLOT(viewTarget(Target*)));
-		QObject::connect(listitem, SIGNAL(editTarget(Target*)),
-                      this, SLOT(editTarget(Target*)));
-		QObject::connect(listitem, SIGNAL(deleteTarget(Target*)),
-                      this, SLOT(deleteTarget(Target*)));
+//		QObject::connect(listitem, SIGNAL(viewTarget(Target*)),
+//                      this, SLOT(viewTarget(Target*)));
+//		QObject::connect(listitem, SIGNAL(editTarget(Target*)),
+//                      this, SLOT(editTarget(Target*)));
+//		QObject::connect(listitem, SIGNAL(deleteTarget(Target*)),
+//                      this, SLOT(deleteTarget(Target*)));
 	}
-	//fnListWidget->setFocusedItem(0);
-	update();
+
+	filterBy(currentFilter);
+
+	fnListWidget->setCurrentRow(0);
+
+	//update();
 }
 
 void eWallet::createMenu()
 {
 	menuBar()->addAction("New", this, SLOT(newTarget()));
+	menuBar()->addAction("Edit", this, SLOT(_editcTarget()));
+	menuBar()->addAction("Invert Sort", this, SLOT(sort()));
 	menuBar()->addAction("Import", this, SLOT(import()));
 	menuBar()->addAction("Export", this, SLOT(exportData()));
 	menuBar()->addAction("About", this, SLOT(about()));
 	menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
 
 }
-/*
-void eWallet::newTarget()
+
+void eWallet::sort()
 {
-	row = -1;
-	if (createTargetDlg.isNull()) {
-		createTargetDlg = new CreateTargetDialog(NULL, this);
-#if defined(Q_OS_WIN32)
-		createTargetDlg->setFixedSize(640,480);
-#elif defined(Q_WS_HILDON)
-		createTargetDlg->setMinimumSize(size().width(),size().height()-100);
-#else
-		createTargetDlg->showMaximized();
-#endif
-		createTargetDlg->exec();
-		delete createTargetDlg;
-		createTargetDlg = 0;
-	}
+	ascSort = !ascSort;
+	showTargets(false);
 }
-*/
-bool eWallet::_insertTarget(Target* target)
+
+bool eWallet::__insertTarget(Target* target)
 {
 	if (::dbManager->insertTarget(target)) {
 		//qDebug () << "Adding new item";
 		::dbManager->updateFields (target);
 		
-		QFNListItem* listitem = new QFNListItem(target, this);
-		//qDebug () << "Adding new item 2";
-		fnListWidget->addItem(listitem, Qt::AlignTop | Qt::AlignLeft);
-		
-		QObject::connect(listitem, SIGNAL(viewTarget(Target*)),
-                      this, SLOT(viewTarget(Target*)));
-		QObject::connect(listitem, SIGNAL(editTarget(Target*)),
-                      this, SLOT(editTarget(Target*)));
-		QObject::connect(listitem, SIGNAL(deleteTarget(Target*)),
-                      this, SLOT(deleteTarget(Target*)));
-					  
-		update ();
-//qDebug () << "Adding new item 4";
+		target->freeFieldList();
+		return true;
+	}
+	return false;
+}
+
+bool eWallet::_insertTarget(Target* target)
+{
+	if (__insertTarget(target)) {
+
+		list.append(target);
+
+//		if (ascSort)
+//			qSort (list.begin(),list.end(),sortTargetsASC);
+//		else
+//			qSort (list.begin(),list.end(),sortTargetsDES);
+
+		QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name, fnListWidget);
+
+		int pos = list.indexOf(target);
+		qDebug () << "position of new " << pos << " OF " << list.size ();
+
+		if (pos < list.size()) {
+			//qDebug () << "insert position of new " << pos << " OF " << list.size ();
+			fnListWidget->insertItem(pos, listitem);
+		}
+		else {
+			//qDebug () << "append position of new " << pos << " OF " << list.size ();
+			fnListWidget->addItem(listitem);
+		}
+		fnListWidget->setCurrentItem(listitem);
 		return true;
 	}
 	return false;
 }
 bool eWallet::_deleteTarget(Target* target)
 {
+	int i = list.indexOf(target);
+	//qDebug () << "DELETE ON " << i;
 	if (::dbManager->deleteTarget(target)) {
-		QFNListItem* listitem = fnListWidget->itemAt (row);
+		list.removeAt(i);
 
-		//disconnect(obj, SIGNAL(destroyed(QObject*)),               this, SLOT(windowDestroyed(QObject*)));
-		QObject::disconnect(listitem, SIGNAL(viewTarget(Target*)),
-                      this, SLOT(viewTarget(Target*)));
-		QObject::disconnect(listitem, SIGNAL(editTarget(Target*)),
-                      this, SLOT(editTarget(Target*)));
-		QObject::disconnect(listitem, SIGNAL(deleteTarget(Target*)),
-                      this, SLOT(deleteTarget(Target*)));
-
-		fnListWidget->removeItem (row);
-
-		update ();
+		fnListWidget->takeItem(i); //oveItem (row);
+//		target->freeFieldList();
+//		target->freeResources();
+//		delete target;
+		delete target;
 		return true;
 	}
 	return false;
 }
 bool eWallet::_updateTarget(Target* target)
 {
+	int i = list.indexOf(target);
+	//qDebug () << "UPDATE ON " << i;
+
 	if (::dbManager->updateTarget(target)) {
 		::dbManager->updateFields (target);
 		
-		if (row >= 0) {
-			fnListWidget->itemAt (row)->setText (target->name);
-		}			
+		target->freeFieldList();
+
+		QListWidgetItem* listitem = fnListWidget->item (i);
+		listitem->setText(target->name);
+		//((QFNListItem*)fnListWidget->currentItem())->setText (target->name);
 		return true;
 	}
 	return false;
@@ -412,10 +511,11 @@ bool eWallet::_updateTarget(Target* target)
 
 bool eWallet::_updateTargetPicture(Target* target)
 {
+	int i = list.indexOf(target);
+	//qDebug () << "UPDATE ON " << i;
 	if (::dbManager->updateTargetPicture(target)) {
-		if (row >= 0) {
-			fnListWidget->itemAt (row)->setImage (target->getPictureSmall(), target->type);
-		}
+		QListWidgetItem* listitem = fnListWidget->item (i);
+		listitem->setIcon(getImage(target));
 		return true;
 	}
 	return false;
@@ -432,7 +532,7 @@ void eWallet::deleteTarget(Target * target) {
 
 	//qDebug()<<"delete ";
 
-	row = fnListWidget->findRow(target);
+	//row = fnListWidget->findRow(target);
 	
 	_deleteTarget (target);
 
@@ -444,6 +544,10 @@ void eWallet::windowDestroyed(QObject* obj)
     disconnect(obj, SIGNAL(destroyed(QObject*)),
                this, SLOT(windowDestroyed(QObject*)));
 
+//    if (currentTarget != NULL) {
+//    	currentTarget->freeFieldList();
+//    }
+
     if (obj == detailWindow.data()) {
 		delete detailWindow;
 		detailWindow = 0;
@@ -458,7 +562,9 @@ void eWallet::windowDestroyed(QObject* obj)
 void eWallet::viewTarget(Target * rent) {
 	//qDebug()<<"view ";
 
-	row = fnListWidget->findRow(rent);
+	//row = fnListWidget->findRow(rent);
+
+	//currentTarget = rent;
 
 	dbManager->getFields(rent);
 
@@ -469,12 +575,12 @@ void eWallet::viewTarget(Target * rent) {
                       this, SLOT(editTarget(Target*)));
 		connect(detailWindow, SIGNAL(newTarget()),
                       this, SLOT(newTarget()));
-#ifdef Q_WS_MAEMO_5
-		detailWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
-#endif
+//#ifdef Q_WS_MAEMO_5
+//#endif
         detailWindow->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindow, SIGNAL(destroyed(QObject*)),
                 this, SLOT(windowDestroyed(QObject*)));
+		detailWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
 	    detailWindow->show(); //owMaximized();
 	}
 }
@@ -482,16 +588,16 @@ void eWallet::viewTarget(Target * rent) {
 void eWallet::editTarget(Target * rent) {
 	//qDebug()<<"edit ";
 
-	row = fnListWidget->findRow(rent);
+	//row = fnListWidget->findRow(rent);
 
 	dbManager->getFields(rent);
 
 	if (detailWindowEdit.isNull()) {
 		detailWindowEdit = new DetailWindow(rent, true, this, this);
-#ifdef Q_WS_MAEMO_5
+//#ifdef Q_WS_MAEMO_5
 		detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
-#endif
-		detailWindowEdit->showMaximized();
+//#endif
+		//detailWindowEdit->showMaximized();
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
                 this, SLOT(windowDestroyed(QObject*)));
@@ -576,7 +682,7 @@ void eWallet::import() {
 						  target->fields.append(field);
 					  }
 
-					  qDebug () << line << " | " << line.mid(j + 1) << " IS " << line.mid (0, j);
+					  //qDebug () << line << " | " << line.mid(j + 1) << " IS " << line.mid (0, j);
 		    	  }
 		    	  else {
 		    		  if (target != NULL && target->fields.size() > 0) {
@@ -593,7 +699,7 @@ void eWallet::import() {
 		    	  i = 0;
 		      }
 
-		      qDebug () << line;
+		      //qDebug () << line;
 		    }
 
 			 if (target != NULL) {
@@ -601,22 +707,21 @@ void eWallet::import() {
 			 }
 		    // Close the file
 		    file.close();
-		  }
 
+		    showTargets (true);
+		  }
 	}
 }
 
 void eWallet::newTarget() {
 	//qDebug()<<"new ";
 
-	row = -1;
-
 	if (detailWindowEdit.isNull()) {
 		detailWindowEdit = new DetailWindow(NULL, true, this, this);
-#ifdef Q_WS_MAEMO_5
+//#ifdef Q_WS_MAEMO_5
 		detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
-#endif
-		detailWindowEdit->showMaximized();
+//#endif
+		//detailWindowEdit->showMaximized();
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
                 this, SLOT(windowDestroyed(QObject*)));
@@ -639,29 +744,6 @@ void eWallet::contextMenuEvent (QContextMenuEvent * event) {
 	}
 }
 */
-/*
-void eWallet::editTarget(Target * rent)
-{
-	row = fnListWidget->findRow(rent);
-
-	qDebug()<<"Edit ";
-
-	if (createTargetDlg.isNull()) {
-			createTargetDlg = new CreateTargetDialog(rent, this);
-#if defined(Q_OS_WIN32)
-			createTargetDlg->setFixedSize(640,480);
-#elif defined(Q_WS_HILDON)
-			createTargetDlg->setMinimumSize(size().width(),size().height()-100);
-#else
-			createTargetDlg->showMaximized();
-#endif
-			createTargetDlg->exec();
-			delete createTargetDlg;
-			createTargetDlg = 0;
-		
-	}
-}
-*/
 
 void eWallet::exportData() {
 	QString path(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
@@ -701,14 +783,23 @@ void eWallet::exportData() {
 		  }
 	}
 }
+
 void eWallet::_editcTarget() {
-	editTarget(this->fnListWidget->itemAt(row)->getSource());
+	if (fnListWidget->currentRow() >= 0) {
+		Target * target = list.at(fnListWidget->currentRow());
+		editTarget(target);
+	}
+	//editTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 void eWallet::_deletecTarget() {
-	deleteTarget(this->fnListWidget->itemAt(row)->getSource());
+	//deleteTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 void eWallet::_viewcTarget() {
-	viewTarget(this->fnListWidget->itemAt(row)->getSource());
+	if (fnListWidget->currentRow() >= 0) {
+		Target * target = list.at(fnListWidget->currentRow());
+		viewTarget(target);
+	}
+	//viewTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 
 //eWallet closeEvent function:
@@ -723,88 +814,23 @@ void eWallet::askPassword () {
 	
 	menuBar()->clear();
 
-//	do {
-		if (loginDialogDlg.isNull()) {
-			loginDialogDlg = new LoginDialog(this);
-			setCentralWidget(loginDialogDlg);
-			loginDialogDlg->setFocus ();
-//	#if defined(Q_OS_WIN32)
-//			loginDialogDlg->setFixedSize(640,480);
-//	#elif defined(Q_WS_HILDON)
-//			loginDialogDlg->setMinimumSize(size().width(),size().height()-100);
-//	#else
-//			loginDialogDlg->showMaximized();
-//	#endif
-//			loginDialogDlg->setFocus();
-//			loginDialogDlg->exec();
-//			delete loginDialogDlg;
-//			loginDialogDlg = 0;
-		}
-		
-		//qDebug () << "TIME " << times;
-			
-//		if (++times > 3) {
-//			exit(3);
-//		}
-//		else {
-//			if (!::dbManager->isReady ()) {
-//				if (messageBox.isNull()) {
-//					messageBox = new QMessageBox(this);
-//					messageBox->information(this, "Wallet", "Wrong password", QMessageBox::Ok);
-//				}
-//				delete messageBox;
-//				messageBox = 0;
-//			}
-//		}
-//	}
-//	while(!::dbManager->isReady ());
+	if (loginDialogDlg.isNull()) {
+		loginDialogDlg = new LoginDialog(!::dbManager->hasPassword (), this);
+
+		// TODO should I remove all included widgets??
+		setCentralWidget(loginDialogDlg);
+		loginDialogDlg->setFocus ();
+
+		centralWidget = NULL;
+		vboxlayout = NULL;
+		fnListWidget = NULL;
+		inputWidget = NULL;
+		cancelSearch = NULL;
+		searchField = NULL;
+		hideSearch = NULL;
+	}
 }
 
 void eWallet::about() {
-	if (aboutDialogDlg.isNull()) {
-		aboutDialogDlg = new AboutDialog(this);
-		aboutDialogDlg->showMaximized();
-#ifdef Q_WS_MAEMO_5
-		aboutDialogDlg->setAttribute(Qt::WA_Maemo5StackedWindow);
-#endif
-		aboutDialogDlg->setAttribute(Qt::WA_DeleteOnClose);
-        //connect(detailWindowEdit, SIGNAL(destroyed(QObject*)), this, SLOT(windowDestroyed(QObject*)));
-        aboutDialogDlg->show();
-	}
+	QMessageBox::about(this, "About qtWallet", TEXT_ABOUT);
 }
-AboutDialog::AboutDialog(QWidget *paTarget) : QMainWindow(paTarget)
-{
-	setContextMenuPolicy(Qt::NoContextMenu);
-
-	QWidget * centralWidget = new QWidget(this);
-	setCentralWidget(centralWidget);
-
-	QVBoxLayout * layout = new QVBoxLayout ();
-
-	QLabel * label;
-
-	label = new QLabel("<qt><br><br><p><i><b>qtWallet</b></i>, v.1.0</p>"
-			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"
-			"<br><br><br>"
-			"<p>if you think that qtWallet is useful for you, please</p></qt>", this);
-	label->setContextMenuPolicy(Qt::NoContextMenu);
-	label->setAlignment(Qt::AlignCenter);
-	layout->addWidget(label);
-
-	label = new QLabel("<qt><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">DONATE</a></qt>", this);
-	label->setContextMenuPolicy(Qt::NoContextMenu);
-	label->setOpenExternalLinks (true);
-	label->setAlignment(Qt::AlignCenter);
-
-	QPixmap available(":/resources/donate.gif");
-	label->setPixmap(available);
-
-	layout->addWidget(label);
-
-	centralWidget->setLayout(layout);
-}
-
-AboutDialog::~AboutDialog()
-{
-}
-
