@@ -9,22 +9,11 @@
 #include <QDebug>
 
 #include "DatabaseManager.h"
-#include "QFNListWidget.h"
-#include "CreateTargetDialog.h"
 #include "DetailedWindow.h"
 #include "LoginDialog.h"
 
 extern DatabaseManager * dbManager;
 
-class AboutDialog: public QMainWindow
-{
-	Q_OBJECT
-
-public:
-	AboutDialog(QWidget * paTarget);
-	~AboutDialog();
-};
-
 class eWallet: public QMainWindow
 {
 	Q_OBJECT
@@ -39,6 +28,7 @@ public:
 	bool _updateTargetPicture(Target* target);
 	bool _updateTargetPictureBack(Target* target);
 	bool _insertTarget(Target* target);
+	bool __insertTarget(Target* target);
 	
 	QList<QString> types;
 	QList<QList<TargetField>*> fieldsByType;
@@ -50,18 +40,23 @@ public slots:
 	void viewTarget(Target * t);
 	Q_SCRIPTABLE void listenInactivity(QString s);
 
+	void selectItem(QListWidgetItem *);
+	void selectDItem(QListWidgetItem *);
+
+	void deleteDB ();
+
 private:
 	void showList ();
 	void keyPressEvent(QKeyEvent*);
-	void timerEvent(QTimerEvent*);
 	void createMenu();
-	void showTargets();
+	void showTargets(bool reset);
 	void loadTypesAndFields ();
 	void filterBy (const QString & s);
-	//void contextMenuEvent (QContextMenuEvent * event);
+	QPixmap getImage (Target * f);
 
 private slots:
     void windowDestroyed(QObject* obj = 0);
+    void sort ();
 	void _editcTarget();
 	void _deletecTarget();
 	void _viewcTarget();
@@ -74,13 +69,13 @@ private slots:
 	void textChanged (const QString &);
 	
 private:
-	//void timerEvent(QTimerEvent *event);
+
 	void askPassword ();
 	void closeEvent(QCloseEvent *event);
 	
 	QVBoxLayout * vboxlayout;
 	int times;
-	QFNListWidget* fnListWidget;
+	QListWidget* fnListWidget;
 	QList<Target *> list;
 
 	QHBoxLayout * inputWidget;
@@ -88,19 +83,17 @@ private:
 	QPushButton * hideSearch;
 	QLineEdit * searchField;
 
-	QPointer<CreateTargetDialog> createTargetDlg;
 	QPointer<LoginDialog> loginDialogDlg;
-	QPointer<AboutDialog> aboutDialogDlg;
 	QPointer<DetailWindow> detailWindow;
 	QPointer<DetailWindow> detailWindowEdit;
 	QWidget* centralWidget;
 	QPointer <QMessageBox> messageBox;
 	bool opendb;
 	bool initdb;
-	
-	int row;
-	
-	QTimer *timer;
+	bool ascSort;
+
+	QString currentFilter;
+
 };
 
 
