@@ -11,10 +11,11 @@
 
 int main(int argc, char *argv[])
 {
-	QApplication a(argc, argv);
-	eWallet* w = new eWallet();
+    QApplication app(argc, argv);
+
+	eWallet * w = new eWallet();
 	w->show();
-	int ret = a.exec();
+	int ret = app.exec();
 	delete w;
 	return ret;
 }
